# The URL for the Vascular Plants of Canada is used in multiple places,
# so specify it here and source it as needed.

## ---- set-url
vascan_url <- "https://data.canadensys.net/ipt/archive.do?r=vascan&v=37.12"
